searchNodes=[{"doc":"This module simplifies :mnesia, and works well with Ecto schemas. It's recommended to surround your code in a try catch as all of the functions will throw up any errors that occur. All of the (non-mnesia) errors that will be thrown will look like {:error, &quot;message&quot;, extra_data}. To use this module, you MUST first use the init!() function, even if you already created a schema. You might want to change the function that automatically sets the time to a format you prefer, by default it's DateTime.utc_now(). After that, you're free to use the rest of the module.","ref":"MnesiaHelper.html","title":"MnesiaHelper","type":"module"},{"doc":"This function creates (deletes if :already_exists ) a table with a name , with all of the keys in attributes_map . attributes_map can either be a normal map, or an Ecto schema (Your map/schema must at least have two keys, one of them always being :id (which must always be nil )). If keys :created_at or :updated_at are present in attributes_map , they are automatically updated, and should almost always (see docs for update!()) be nil . Any extra indexes need to be listed as atoms in index_list . Any other options should be passed to extra_opts as a keylist (the same way you would normally pass it to :mnesia.create_table()). This function returns :ok . If any mistake (except :already_exists ) occurs, this function will throw an error. Examples iex&gt; create_table! ( :people , %{ id : nil , name : nil , age : nil , created_at : nil , updated_at : nil } ) :ok","ref":"MnesiaHelper.html#create_table!/4","title":"MnesiaHelper.create_table!/4","type":"function"},{"doc":"This function returns a list of all keys that are present inside a table named name . This function returns a list of atoms. If any mistake occurs, this function will throw an error. Examples iex&gt; get_keys! ( :people ) [ :id , :age , :created_at , :name , :updated_at ]","ref":"MnesiaHelper.html#get_keys!/1","title":"MnesiaHelper.get_keys!/1","type":"function"},{"doc":"This function returns all records from a table named name where index == input . This function returns a list of maps. If there are no records that match, it returns an empty list. If any mistake occurs, this function will throw an error. Examples iex&gt; index_read! ( :people , 0 , :id ) [ %{ age : 25 , created_at : ~U[2022-05-31 17:56:38.658000Z] , id : 0 , name : &quot;John&quot; , updated_at : ~U[2022-05-31 17:57:19.492000Z] } ]","ref":"MnesiaHelper.html#index_read!/3","title":"MnesiaHelper.index_read!/3","type":"function"},{"doc":"This function creates a schema using the passed nodes , starts mnesia and returns :ok . If any mistake (except :already_exists ) occurs, this function will throw an error. Examples iex&gt; init! ( ) :ok","ref":"MnesiaHelper.html#init!/1","title":"MnesiaHelper.init!/1","type":"function"},{"doc":"This function matches the given map/structure input with any records that exist in table named name . This function returns a list of maps. If there are no records that match, it returns an empty list. If any mistake occurs, this function will throw an error. Examples iex&gt; match! ( :people , %{ name : &quot;John&quot; } ) [ %{ age : 25 , created_at : ~U[2022-05-31 17:56:38.658000Z] , id : 0 , name : &quot;John&quot; , updated_at : ~U[2022-05-31 17:57:19.492000Z] } ]","ref":"MnesiaHelper.html#match!/2","title":"MnesiaHelper.match!/2","type":"function"},{"doc":"This function selects any records from a table named name where all guards are true and returns only the keys in columns . All guards are the same as in a regular :mnesia.select(), however, instead of an ambiguous lambda symbol, you can use any keys that are inside this table's attributes. Be default columns is empty and returns every column in record. This function returns a list of maps. If there are no records that match, it returns an empty list. If any mistake occurs, this function will throw an error. Examples iex&gt; select_all! ( :people , [ { :&gt; , :age , 21 } ] ) [ %{ age : 25 , created_at : ~U[2022-05-31 17:56:38.658000Z] , id : 0 , name : &quot;John&quot; , updated_at : ~U[2022-05-31 17:57:19.492000Z] } ]","ref":"MnesiaHelper.html#select!/3","title":"MnesiaHelper.select!/3","type":"function"},{"doc":"Use this function to set a function that will determine the datetime that is set in :created_at and :updated_at . By default that function is fn -&gt; DateTime.utc_now() end . Examples iex&gt; set_time_fn ( fn -&gt; DateTime . utc_now ( ) |&gt; DateTime . to_iso8601 ( ) end ) :ok","ref":"MnesiaHelper.html#set_time_fn/1","title":"MnesiaHelper.set_time_fn/1","type":"function"},{"doc":"This function overwrites all values under key :id == id inside the table named name by input . IMPORTANT: If key :created_at is present in the table attributes, it should be set in input , as otherwise the function will have to pull this value from the original record, which INCREASES time to execute this function by about 1.5 times. This function returns :ok . Key :updated_at is always ignored as it is automatically set if it is present in table attributes. If any mistake occurs, this function will throw an error. Examples iex&gt; update! ( :people , %{ name : &quot;John&quot; , age : 25 } , 0 ) :ok","ref":"MnesiaHelper.html#update!/3","title":"MnesiaHelper.update!/3","type":"function"},{"doc":"This function writes all values in map/struct input into a table named name . Keys :created_at , :updated_at and :id are always ignored as they are automatically set if they are present in table attributes. This function returns :ok . If any mistake occurs, this function will throw an error. Examples iex&gt; write! ( :people , %{ name : &quot;John&quot; , age : 21 } ) :ok","ref":"MnesiaHelper.html#write!/2","title":"MnesiaHelper.write!/2","type":"function"}]